@@ -40,7 +40,9 @@ read_ini <- function(file_name) {
     found_nested_content <- nested_contents[items]
     if (any(found_nested_content)) {
       profiles[[i]] <- nested_ini_content(
-        split_content[items, , drop = FALSE], found_nested_content, which(sub_grps[items])
+        split_content[items, , drop = FALSE],
+        found_nested_content,
+        which(sub_grps[items])
       )
     } else {
       profiles[[i]] <- extract_ini_parameter(split_content[items, , drop = FALSE])
@@ -63,7 +65,11 @@ nested_ini_content <- function(sub_content, found_nested_content, sub_grp) {
   end <- c(sub_grp[-1] - 1, nrow(sub_content))
   for (i in which(start <= end)) {
     items <- seq.int(start[i], end[i])
-    profiles[[profile_nms[i]]] <- extract_ini_parameter(sub_content[items, , drop = FALSE])
+    profiles[[profile_nms[i]]] <- extract_ini_parameter(sub_content[
+      items,
+      ,
+      drop = FALSE
+    ])
   }
   return(profiles)
 }
